@@ -61,7 +61,6 @@ struct __fehoptions {
 	unsigned char no_menus;
 	unsigned char scale_down;
 	unsigned char builtin_http;
-	unsigned char wget_timestamp;
 	unsigned char bgmode;
 	unsigned char xinerama;
 	unsigned char screen_clip;
@@ -132,7 +131,6 @@ struct __fehoptions {
 
 void init_parse_options(int argc, char **argv);
 char *feh_string_normalize(char *str);
-void feh_create_default_config(char *rcfile);
 
 extern fehoptions opt;
 
